
#ifndef TEXTAUTOGENERATETEXT_EXPORT_H
#define TEXTAUTOGENERATETEXT_EXPORT_H

#ifdef TEXTAUTOGENERATETEXT_STATIC_DEFINE
#  define TEXTAUTOGENERATETEXT_EXPORT
#  define TEXTAUTOGENERATETEXT_NO_EXPORT
#else
#  ifndef TEXTAUTOGENERATETEXT_EXPORT
#    ifdef KF6TextAutoGenerateText_EXPORTS
        /* We are building this library */
#      define TEXTAUTOGENERATETEXT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOGENERATETEXT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOGENERATETEXT_NO_EXPORT
#    define TEXTAUTOGENERATETEXT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOGENERATETEXT_DEPRECATED
#  define TEXTAUTOGENERATETEXT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOGENERATETEXT_DEPRECATED_EXPORT
#  define TEXTAUTOGENERATETEXT_DEPRECATED_EXPORT TEXTAUTOGENERATETEXT_EXPORT TEXTAUTOGENERATETEXT_DEPRECATED
#endif

#ifndef TEXTAUTOGENERATETEXT_DEPRECATED_NO_EXPORT
#  define TEXTAUTOGENERATETEXT_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXT_NO_EXPORT TEXTAUTOGENERATETEXT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOGENERATETEXT_NO_DEPRECATED
#    define TEXTAUTOGENERATETEXT_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTAUTOGENERATETEXT_EXPORT_H */
