// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTEMOTICONSWIDGETS_VERSION_H
#define TEXTEMOTICONSWIDGETS_VERSION_H

#define TEXTEMOTICONSWIDGETS_VERSION_STRING "2.0.2"
#define TEXTEMOTICONSWIDGETS_VERSION_MAJOR 2
#define TEXTEMOTICONSWIDGETS_VERSION_MINOR 0
#define TEXTEMOTICONSWIDGETS_VERSION_PATCH 2
#define TEXTEMOTICONSWIDGETS_VERSION ((2<<16)|(0<<8)|(2))

#endif
