
#ifndef TEXTTRANSLATOR_EXPORT_H
#define TEXTTRANSLATOR_EXPORT_H

#ifdef TEXTTRANSLATOR_STATIC_DEFINE
#  define TEXTTRANSLATOR_EXPORT
#  define TEXTTRANSLATOR_NO_EXPORT
#else
#  ifndef TEXTTRANSLATOR_EXPORT
#    ifdef KF6TextTranslator_EXPORTS
        /* We are building this library */
#      define TEXTTRANSLATOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTTRANSLATOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTTRANSLATOR_NO_EXPORT
#    define TEXTTRANSLATOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTTRANSLATOR_DEPRECATED
#  define TEXTTRANSLATOR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTTRANSLATOR_DEPRECATED_EXPORT
#  define TEXTTRANSLATOR_DEPRECATED_EXPORT TEXTTRANSLATOR_EXPORT TEXTTRANSLATOR_DEPRECATED
#endif

#ifndef TEXTTRANSLATOR_DEPRECATED_NO_EXPORT
#  define TEXTTRANSLATOR_DEPRECATED_NO_EXPORT TEXTTRANSLATOR_NO_EXPORT TEXTTRANSLATOR_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTTRANSLATOR_NO_DEPRECATED
#    define TEXTTRANSLATOR_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTTRANSLATOR_EXPORT_H */
