
#ifndef TEXTSPEECHTOTEXT_EXPORT_H
#define TEXTSPEECHTOTEXT_EXPORT_H

#ifdef TEXTSPEECHTOTEXT_STATIC_DEFINE
#  define TEXTSPEECHTOTEXT_EXPORT
#  define TEXTSPEECHTOTEXT_NO_EXPORT
#else
#  ifndef TEXTSPEECHTOTEXT_EXPORT
#    ifdef KF6TextSpeechToText_EXPORTS
        /* We are building this library */
#      define TEXTSPEECHTOTEXT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTSPEECHTOTEXT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTSPEECHTOTEXT_NO_EXPORT
#    define TEXTSPEECHTOTEXT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTSPEECHTOTEXT_DEPRECATED
#  define TEXTSPEECHTOTEXT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTSPEECHTOTEXT_DEPRECATED_EXPORT
#  define TEXTSPEECHTOTEXT_DEPRECATED_EXPORT TEXTSPEECHTOTEXT_EXPORT TEXTSPEECHTOTEXT_DEPRECATED
#endif

#ifndef TEXTSPEECHTOTEXT_DEPRECATED_NO_EXPORT
#  define TEXTSPEECHTOTEXT_DEPRECATED_NO_EXPORT TEXTSPEECHTOTEXT_NO_EXPORT TEXTSPEECHTOTEXT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTSPEECHTOTEXT_NO_DEPRECATED
#    define TEXTSPEECHTOTEXT_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTSPEECHTOTEXT_EXPORT_H */
