/*
  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#define HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT 1
#define HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT 1
