
#ifndef TEXTGRAMMARCHECK_EXPORT_H
#define TEXTGRAMMARCHECK_EXPORT_H

#ifdef TEXTGRAMMARCHECK_STATIC_DEFINE
#  define TEXTGRAMMARCHECK_EXPORT
#  define TEXTGRAMMARCHECK_NO_EXPORT
#else
#  ifndef TEXTGRAMMARCHECK_EXPORT
#    ifdef KF6TextGrammarCheck_EXPORTS
        /* We are building this library */
#      define TEXTGRAMMARCHECK_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTGRAMMARCHECK_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTGRAMMARCHECK_NO_EXPORT
#    define TEXTGRAMMARCHECK_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTGRAMMARCHECK_DEPRECATED
#  define TEXTGRAMMARCHECK_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTGRAMMARCHECK_DEPRECATED_EXPORT
#  define TEXTGRAMMARCHECK_DEPRECATED_EXPORT TEXTGRAMMARCHECK_EXPORT TEXTGRAMMARCHECK_DEPRECATED
#endif

#ifndef TEXTGRAMMARCHECK_DEPRECATED_NO_EXPORT
#  define TEXTGRAMMARCHECK_DEPRECATED_NO_EXPORT TEXTGRAMMARCHECK_NO_EXPORT TEXTGRAMMARCHECK_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTGRAMMARCHECK_NO_DEPRECATED
#    define TEXTGRAMMARCHECK_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTGRAMMARCHECK_EXPORT_H */
